//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useState, useEffect } from "react";
import { sendMessage } from "primeobjects-ui-web-store/build/cjs/center/message";
import { AuthSectionLink } from "./util";
import { callApiBase, getApiRootError } from "primeobjects-ui-web-application/build/cjs/util";
import { getPrimaryColor } from "primeobjects-helper-ui";
import SVG from "primeobjects-ui-web-basic/build/cjs/controls/svg";
import { useRouter } from "next/navigation";
import { getCookie, setCookie } from "primeobjects-ui-web-basic/build/cjs/util/cookie";
import { isEmail, isNonEmptyString } from "primeobjects-helper-util";
import Lottie from "primeobjects-ui-web-basic/build/cjs/controls/lottie";
export var SignUpSection = function (props) {
    var _a;
    var router = useRouter();
    var supportSSO = props.supportSSO, SignUpForm = props.SignUpForm, agreement = props.agreement, solution = props.solution;
    var _b = useState(""), doing = _b[0], setDoing = _b[1];
    var _c = useState(false), showAgreement = _c[0], setShowAgreement = _c[1];
    var _d = useState(""), errorMessage = _d[0], setErrorMessage = _d[1];
    var _e = useState({}), data = _e[0], setData = _e[1];
    var primaryColor = getPrimaryColor(solution);
    var buttonColorName = props.buttonColorName
        ? props.buttonColorName
        : primaryColor.name;
    useEffect(function () {
        var _a, _b;
        var newData = __assign(__assign({}, props.data), { email: ((_a = props.data) === null || _a === void 0 ? void 0 : _a.email)
                ? (_b = props.data) === null || _b === void 0 ? void 0 : _b.email
                : getCookie("sign-up-email") });
        setData(newData);
    }, [props.data]);
    var onChangeData = function (newData) {
        setData(newData);
        setErrorMessage("");
        if (props.onChangeData)
            props.onChangeData(newData);
    };
    var onSignUpError = function (error) {
        setDoing("");
        setErrorMessage(error);
        if (props.onSignUpError)
            props.onSignUpError(error);
    };
    var onSuccess = function () {
        if (props.onSuccess) {
            if (!props.onSuccess(data)) {
                setDoing("");
            }
        }
        else {
            setCookie("sign-in-email", data.email);
            router.push("/auth/activate-without-password?result=sign-up-success");
        }
    };
    var onClickSignIn = function () {
        if (props.onClickSignIn) {
            props.onClickSignIn(data);
        }
        else {
            router.push("/auth/sign-in");
        }
    };
    var onSubmit = function () {
        var _a, _b;
        if (!isEmail(data.email)) {
            return setErrorMessage("Please provide your email.");
        }
        if (!isNonEmptyString(data.role)) {
            var signUpRoles = (_b = (_a = solution === null || solution === void 0 ? void 0 : solution.signUp) === null || _a === void 0 ? void 0 : _a.roles) !== null && _b !== void 0 ? _b : [];
            switch (signUpRoles.length) {
                case 0: {
                    data.role = "ORG-ADMIN";
                    break;
                }
                case 1: {
                    data.role = signUpRoles[0].value;
                    break;
                }
                default: {
                    return setErrorMessage("Please select a role.");
                }
            }
        }
        if (!isNonEmptyString(data.password)) {
            return setErrorMessage("Please provide your password.");
        }
        if (data.password != data.confirmPassword) {
            return setErrorMessage("Your password and confirmation password do not match.");
        }
        if (!data.signedAgreement && (agreement === null || agreement === void 0 ? void 0 : agreement.title)) {
            return setErrorMessage("Please read the Agreement & Notice and select 'I have read' checkbox.");
        }
        setErrorMessage("");
        setDoing("Processing ...");
        callApiBase(
        // "http://localhost:3000/prod/sign-up",
        "".concat(solution.apis.organization, "sign-up"), data, "POST", { solutionId: solution.id })
            .then(function (result) {
            if (result.error) {
                console.error(result.error);
                setDoing("");
                switch (result.error) {
                    case "ERROR_SIGNIN_NEED_EMAIL": {
                        return onSignUpError("Please provide a valid email.");
                    }
                    case "ERROR_SIGNIN_NEED_PASSWORD": {
                        return onSignUpError("Please provide a valid password.");
                    }
                    case "ERROR_SIGNIN_USERNOTFOUND": {
                        return onSignUpError("The user does not exist.");
                    }
                    default: {
                        return onSignUpError("Failed to sign up (".concat(result.error, ")."));
                    }
                }
            }
            sendMessage("context-sign-up-success", "action", result);
            onSuccess();
        })
            .catch(function (error) {
            var _a, _b;
            console.error({ error: error });
            var rootError = getApiRootError(error);
            if ((rootError === null || rootError === void 0 ? void 0 : rootError.type) == "ERROR_USER_EXIST" ||
                ((_b = (_a = rootError === null || rootError === void 0 ? void 0 : rootError.error) === null || _a === void 0 ? void 0 : _a.detail) === null || _b === void 0 ? void 0 : _b.reason) == "user-exist") {
                return onSignUpError("There is already a user with the same email.");
            }
            else {
                return onSignUpError("Failed to sign up.");
            }
        });
    };
    var renderSSO = function () {
        return (supportSSO && (React.createElement(React.Fragment, null,
            React.createElement("div", { className: "relative flex space-x-3" },
                React.createElement("div", { className: "min-w-0 flex-1 pt-1.5 flex justify-between space-x-4" },
                    React.createElement("div", { className: "text-base" }, "Sign up with social accounts"))),
            React.createElement("div", { className: "mt-5 mb-10 py-10 pl-8 border-0 border-l ml-3" },
                React.createElement("button", { style: { maxWidth: 250 }, className: "mb-5 w-full flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium bg-gray-100 hover:bg-gray-200 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-".concat(buttonColorName, "-500") },
                    React.createElement(SVG, { src: "/icons/logo-google.svg", className: "flex justify-center", style: { width: 20, marginRight: 10 } }),
                    "Google"),
                React.createElement("button", { style: { maxWidth: 250 }, className: "mb-5 w-full flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium bg-gray-100 hover:bg-gray-200 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-".concat(buttonColorName, "-500") },
                    React.createElement(SVG, { src: "/icons/logo-facebook.svg", className: "flex justify-center", style: { width: 20, marginRight: 10 } }),
                    "Facebook")))));
    };
    var onYesAgreement = function () {
        setData(__assign(__assign({}, data), { signedAgreement: true }));
        setShowAgreement(false);
    };
    var onNoAgreement = function () {
        setData(__assign(__assign({}, data), { signedAgreement: false }));
        setShowAgreement(false);
    };
    var onShowAgreement = function () {
        setShowAgreement(true);
    };
    return (React.createElement("div", { className: "mx-auto w-full max-w-md lg:w-96 ".concat(props.wrapperClassName ? props.wrapperClassName : ""), style: props.wrapperStyle ? props.wrapperStyle : {} },
        props.message && React.createElement("div", { className: "w-full" }, props.message),
        React.createElement("div", null,
            React.createElement("h2", { className: "mt-6 text-3xl font-extrabold text-gray-900" }, "Sign up your account")),
        React.createElement("div", { className: "mt-8" },
            renderSSO(),
            supportSSO && (React.createElement("div", { className: "relative flex space-x-3" },
                React.createElement("div", { className: "h-8 w-8 rounded-full bg-green-500 flex flex- items-center justify-center ring-8 ring-white" },
                    React.createElement("svg", { className: "h-5 w-5 text-white", "x-description": "Heroicon name: solid/check", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 20 20", fill: "currentColor", "aria-hidden": "true" },
                        React.createElement("path", { fillRule: "evenodd", d: "M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z", clipRule: "evenodd" }))),
                React.createElement("div", { className: "min-w-0 flex-1 pt-1.5 flex justify-between space-x-4" },
                    React.createElement("span", { className: "text-base" }, "Or sign in with your email")))),
            React.createElement("div", { className: supportSSO
                    ? "mt-5 py-10 pl-8 border-0 border-l ml-3"
                    : "py-6" },
                !showAgreement && (React.createElement(SignUpForm, { agreement: agreement, data: data, onChangeData: onChangeData, solution: solution, alwaysShowLabel: true, errorMessage: errorMessage, onSubmitConfirmedPassword: onSubmit, onShowAgreement: onShowAgreement, doing: doing }, props.children)),
                doing && !showAgreement && (React.createElement("div", { className: "w-full" },
                    React.createElement("div", { style: {
                            width: 50,
                            height: 50
                        } },
                        React.createElement(Lottie, { className: "w-full h-full", url: "/icons/platform/lottie/dots-2.json", colors: Array(6).fill(primaryColor["600"]) })))),
                !doing && !showAgreement && (React.createElement("button", { className: "my-8 flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-".concat(buttonColorName, "-600 hover:bg-").concat(buttonColorName, "-700"), onClick: onSubmit }, "Submit")),
                !doing && showAgreement && (agreement === null || agreement === void 0 ? void 0 : agreement.content) && (React.createElement("div", { className: "w-full overflow-y-auto w-full border rounded py-1 px-2", style: { minHeight: 200, maxHeight: 400 }, dangerouslySetInnerHTML: {
                        __html: agreement === null || agreement === void 0 ? void 0 : agreement.content
                    } })),
                !doing && showAgreement && (agreement === null || agreement === void 0 ? void 0 : agreement.content) && (React.createElement("div", { className: "w-full flex flex-row" },
                    React.createElement("button", { className: "my-10 w-full mr-4 flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-emerald-600 hover:bg-emerald-700", onClick: onYesAgreement }, "Agree"),
                    React.createElement("button", { className: "my-10 w-full flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium bg-gray-100 hover:bg-gray-200", onClick: onNoAgreement }, "Disagree"))),
                !doing &&
                    ((_a = solution === null || solution === void 0 ? void 0 : solution.site) === null || _a === void 0 ? void 0 : _a.supportSignUp) != false &&
                    !showAgreement && (React.createElement(AuthSectionLink, { text: "Have a user account already? Click here to sign in.", onClick: onClickSignIn }))))));
};
export default SignUpSection;
//# sourceMappingURL=sign-up.js.map